@@ -148,7 +148,7 @@ void l7vs::logger_implement_access::putLog(
     catch (const std::exception& ex) {
         std::ostringstream oss;
         oss << "Logging Error (Access Log) : " << ex.what();
-        std::cout << oss.str() << "\n";
+        std::cout << oss.str() << "¥n";
     }
 
 }
